@@ -29,14 +29,13 @@
 #include <string.h>
 #include <panel-applet.h>
 #include <gtk/gtk.h>
-#include <gtk/gtkbox.h>
-#include <libgnomeui/gnome-help.h>
 #include <gdk/gdkkeysyms.h>
-#include <libdbus-watch.h>
 #include <glib-object.h>
 #include <dbus/dbus-glib.h>
 
-#include "../src/gpm-common.h"
+#include "egg-debug.h"
+#include "egg-dbus-monitor.h"
+#include "gpm-common.h"
 
 #define GPM_TYPE_BRIGHTNESS_APPLET		(gpm_brightness_applet_get_type ())
 #define GPM_BRIGHTNESS_APPLET(o)		(G_TYPE_CHECK_INSTANCE_CAST ((o), GPM_TYPE_BRIGHTNESS_APPLET, GpmBrightnessApplet))
@@ -58,7 +57,7 @@ typedef struct{
 	/* connection to g-p-m */
 	DBusGProxy *proxy;
 	DBusGConnection *connection;
-	DbusWatch *watch;
+	EggDbusMonitor *monitor;
 	guint level;
 	/* a cache for panel size */
 	gint size;
@@ -120,7 +119,7 @@ gpm_applet_get_brightness (GpmBrightnessApplet *applet)
 	guint policy_brightness;
 
 	if (applet->proxy == NULL) {
-		printf ("WARNING: not connected\n");
+		egg_warning ("not connected\n");
 		return FALSE;
 	}
 
@@ -129,14 +128,14 @@ gpm_applet_get_brightness (GpmBrightnessApplet *applet)
 				 G_TYPE_UINT, &policy_brightness,
 				 G_TYPE_INVALID);
 	if (error) {
-		printf ("DEBUG: ERROR: %s\n", error->message);
+		egg_debug ("ERROR: %s\n", error->message);
 		g_error_free (error);
 	}
-	if (ret == TRUE) {
+	if (ret) {
 		applet->level = policy_brightness;
 	} else {
 		/* abort as the DBUS method failed */
-		printf ("WARNING: GetBrightness failed!\n");
+		egg_warning ("GetBrightness failed!\n");
 	}
 
 	return ret;
@@ -153,7 +152,7 @@ gpm_applet_set_brightness (GpmBrightnessApplet *applet)
 	gboolean ret;
 
 	if (applet->proxy == NULL) {
-		printf ("WARNING: not connected");
+		egg_warning ("not connected");
 		return FALSE;
 	}
 
@@ -162,12 +161,12 @@ gpm_applet_set_brightness (GpmBrightnessApplet *applet)
 				 G_TYPE_INVALID,
 				 G_TYPE_INVALID);
 	if (error) {
-		printf ("DEBUG: ERROR: %s", error->message);
+		egg_debug ("ERROR: %s", error->message);
 		g_error_free (error);
 	}
-	if (ret == FALSE) {
+	if (!ret) {
 		/* abort as the DBUS method failed */
-		printf ("WARNING: SetBrightness failed!");
+		egg_warning ("SetBrightness failed!");
 	}
 
 	return ret;
@@ -207,9 +206,9 @@ gpm_applet_get_icon (GpmBrightnessApplet *applet)
 						 icon, applet->size - 2, 0, NULL);
 
 	if (applet->icon == NULL) {
-		printf ("WARNING: Cannot find %s!\n", icon);
+		egg_warning ("Cannot find %s!\n", icon);
 	} else {
-		printf ("DEBUG: got icon %s!\n", icon);
+		egg_debug ("got icon %s!\n", icon);
 		/* update size cache */
 		applet->icon_height = gdk_pixbuf_get_height (applet->icon);
 		applet->icon_width = gdk_pixbuf_get_width (applet->icon);
@@ -225,17 +224,20 @@ gpm_applet_get_icon (GpmBrightnessApplet *applet)
 static void
 gpm_applet_check_size (GpmBrightnessApplet *applet)
 {
+	GtkAllocation allocation;
+
 	/* we don't use the size function here, but the yet allocated size because the
 	   size value is false (kind of rounded) */
+	gtk_widget_get_allocation (GTK_WIDGET (applet), &allocation);
 	if (PANEL_APPLET_VERTICAL(panel_applet_get_orient (PANEL_APPLET (applet)))) {
-		if (applet->size != GTK_WIDGET(applet)->allocation.width) {
-			applet->size = GTK_WIDGET(applet)->allocation.width;
+		if (applet->size != allocation.width) {
+			applet->size = allocation.width;
 			gpm_applet_get_icon (applet);
 			gtk_widget_set_size_request (GTK_WIDGET(applet), applet->size, applet->icon_height + 2);
 		}
 	} else {
-		if (applet->size != GTK_WIDGET(applet)->allocation.height) {
-			applet->size = GTK_WIDGET(applet)->allocation.height;
+		if (applet->size != allocation.height) {
+			applet->size = allocation.height;
 			gpm_applet_get_icon (applet);
 			gtk_widget_set_size_request (GTK_WIDGET(applet), applet->icon_width + 2, applet->size);
 		}
@@ -255,8 +257,9 @@ gpm_applet_draw_cb (GpmBrightnessApplet *applet)
 	GdkColor color;
 	GdkGC *gc;
 	GdkPixmap *background;
+	GtkAllocation allocation;
 
-	if (GTK_WIDGET(applet)->window == NULL) {
+	if (gtk_widget_get_window (GTK_WIDGET(applet)) == NULL) {
 		return FALSE;
 	}
 
@@ -272,23 +275,24 @@ gpm_applet_draw_cb (GpmBrightnessApplet *applet)
 		return FALSE;
 	}
 
-	w = GTK_WIDGET(applet)->allocation.width;
-	h = GTK_WIDGET(applet)->allocation.height;
+	gtk_widget_get_allocation (GTK_WIDGET (applet), &allocation);
+	w = allocation.width;
+	h = allocation.height;
 
-	gc = gdk_gc_new (GTK_WIDGET(applet)->window);
+	gc = gdk_gc_new (gtk_widget_get_window (GTK_WIDGET(applet)));
 
 	/* draw pixmap background */
 	bg_type = panel_applet_get_background (PANEL_APPLET (applet), &color, &background);
 	if (bg_type == PANEL_PIXMAP_BACKGROUND && !applet->popped) {
 		/* fill with given background pixmap */
-		gdk_draw_drawable (GTK_WIDGET(applet)->window, gc, background, 0, 0, 0, 0, w, h);
+		gdk_draw_drawable (gtk_widget_get_window (GTK_WIDGET(applet)), gc, background, 0, 0, 0, 0, w, h);
 	}
 	
 	/* draw color background */
 	if (bg_type == PANEL_COLOR_BACKGROUND && !applet->popped) {
 		gdk_gc_set_rgb_fg_color (gc,&color);
 		gdk_gc_set_fill (gc,GDK_SOLID);
-		gdk_draw_rectangle (GTK_WIDGET(applet)->window, gc, TRUE, 0, 0, w, h);
+		gdk_draw_rectangle (gtk_widget_get_window (GTK_WIDGET(applet)), gc, TRUE, 0, 0, w, h);
 	}
 
 	/* fill with selected color if popped */
@@ -296,11 +300,11 @@ gpm_applet_draw_cb (GpmBrightnessApplet *applet)
 		color = gtk_rc_get_style (GTK_WIDGET(applet))->bg[GTK_STATE_SELECTED];
 		gdk_gc_set_rgb_fg_color (gc,&color);
 		gdk_gc_set_fill (gc,GDK_SOLID);
-		gdk_draw_rectangle (GTK_WIDGET(applet)->window, gc, TRUE, 0, 0, w, h);
+		gdk_draw_rectangle (gtk_widget_get_window (GTK_WIDGET(applet)), gc, TRUE, 0, 0, w, h);
 	}
 
 	/* draw icon at center */
-	gdk_draw_pixbuf (GTK_WIDGET(applet)->window, gc, applet->icon,
+	gdk_draw_pixbuf (gtk_widget_get_window (GTK_WIDGET(applet)), gc, applet->icon,
 			 0, 0, (w - applet->icon_width)/2, (h - applet->icon_height)/2,
 			 applet->icon_width, applet->icon_height,
 			 GDK_RGB_DITHER_NONE, 0, 0);
@@ -349,19 +353,20 @@ gpm_applet_destroy_popup_cb (GpmBrightnessApplet *applet)
 static void
 gpm_applet_update_tooltip (GpmBrightnessApplet *applet)
 {
-	static gchar buf[101];
+	gchar *buf = NULL;
 	if (applet->popped == FALSE) {
 		if (applet->proxy == NULL) {
-			snprintf (buf, 100, _("Cannot connect to gnome-power-manager"));
+			buf = g_strdup (_("Cannot connect to gnome-power-manager"));
 		} else if (applet->call_worked == FALSE) {
-			snprintf (buf, 100, _("Cannot get laptop panel brightness"));
+			buf = g_strdup (_("Cannot get laptop panel brightness"));
 		} else {
-			snprintf (buf, 100, _("LCD brightness : %d%%"), applet->level);
+			buf = g_strdup_printf (_("LCD brightness : %d%%"), applet->level);
 		}
 		gtk_widget_set_tooltip_text (GTK_WIDGET(applet), buf);
 	} else {
 		gtk_widget_set_tooltip_text (GTK_WIDGET(applet), NULL);
 	}
+	g_free (buf);
 }
 
 /**
@@ -605,6 +610,7 @@ gpm_applet_create_popup (GpmBrightnessApplet *applet)
 static gboolean
 gpm_applet_popup_cb (GpmBrightnessApplet *applet, GdkEventButton *event)
 {
+	GtkAllocation allocation, popup_allocation;
 	gint orientation, x, y;
 
 	/* react only to left mouse button */
@@ -644,36 +650,32 @@ gpm_applet_popup_cb (GpmBrightnessApplet *applet, GdkEventButton *event)
 
 	/* retrieve geometry parameters and move window appropriately */
 	orientation = panel_applet_get_orient (PANEL_APPLET (PANEL_APPLET (applet)));
-	gdk_window_get_origin (GTK_WIDGET(applet)->window, &x, &y);
+	gdk_window_get_origin (gtk_widget_get_window (GTK_WIDGET(applet)), &x, &y);
 
+	gtk_widget_get_allocation (GTK_WIDGET (applet), &allocation);
+	gtk_widget_get_allocation (GTK_WIDGET (applet->popup), &popup_allocation);
 	switch (orientation) {
 	case PANEL_APPLET_ORIENT_DOWN:
-		x += GTK_WIDGET(applet)->allocation.x
-			+ GTK_WIDGET(applet)->allocation.width/2;
-		y += GTK_WIDGET(applet)->allocation.y
-			+ GTK_WIDGET(applet)->allocation.height;
-		x -= applet->popup->allocation.width/2;
+		x += allocation.x + allocation.width/2;
+		y += allocation.y + allocation.height;
+		x -= popup_allocation.width/2;
 		break;
 	case PANEL_APPLET_ORIENT_UP:
-		x += GTK_WIDGET(applet)->allocation.x
-			+ GTK_WIDGET(applet)->allocation.width/2;
-		y += GTK_WIDGET(applet)->allocation.y;
-		x -= applet->popup->allocation.width/2;
-		y -= applet->popup->allocation.height;
+		x += allocation.x + allocation.width/2;
+		y += allocation.y;
+		x -= popup_allocation.width/2;
+		y -= popup_allocation.height;
 		break;
 	case PANEL_APPLET_ORIENT_RIGHT:
-		y += GTK_WIDGET(applet)->allocation.y
-			+ GTK_WIDGET(applet)->allocation.height/2;
-		x += GTK_WIDGET(applet)->allocation.x
-			+ GTK_WIDGET(applet)->allocation.width;
-		y -= applet->popup->allocation.height/2;
+		y += allocation.y + allocation.height/2;
+		x += allocation.x + allocation.width;
+		y -= popup_allocation.height/2;
 		break;
 	case PANEL_APPLET_ORIENT_LEFT:
-		y += GTK_WIDGET(applet)->allocation.y
-			+ GTK_WIDGET(applet)->allocation.height/2;
-		x += GTK_WIDGET(applet)->allocation.x;
-		x -= applet->popup->allocation.width;
-		y -= applet->popup->allocation.height/2;
+		y += allocation.y + allocation.height/2;
+		x += allocation.x;
+		x -= popup_allocation.width;
+		y -= popup_allocation.height/2;
 		break;
 	default:
 		g_assert_not_reached ();
@@ -684,12 +686,12 @@ gpm_applet_popup_cb (GpmBrightnessApplet *applet, GdkEventButton *event)
 	/* grab input */
 	gtk_widget_grab_focus (GTK_WIDGET(applet));
 	gtk_grab_add (GTK_WIDGET(applet));
-	gdk_pointer_grab (GTK_WIDGET(applet)->window, TRUE,
+	gdk_pointer_grab (gtk_widget_get_window (GTK_WIDGET(applet)), TRUE,
 			  GDK_BUTTON_PRESS_MASK |
 			  GDK_BUTTON_RELEASE_MASK |
 			  GDK_POINTER_MOTION_MASK,
 			  NULL, NULL, GDK_CURRENT_TIME);
-	gdk_keyboard_grab (GTK_WIDGET(applet)->window,
+	gdk_keyboard_grab (gtk_widget_get_window (GTK_WIDGET(applet)),
 			   TRUE, GDK_CURRENT_TIME);
 	gtk_widget_set_state (GTK_WIDGET(applet), GTK_STATE_SELECTED);
 
@@ -765,7 +767,7 @@ gpm_applet_dialog_about_cb (BonoboUIComponent *uic, gpointer data, const gchar *
 				     _(license[2]), "\n\n", _(license[3]), "\n", NULL);
 
 	about = (GtkAboutDialog*) gtk_about_dialog_new ();
-	gtk_about_dialog_set_name (about, GPM_BRIGHTNESS_APPLET_NAME);
+	gtk_about_dialog_set_program_name (about, GPM_BRIGHTNESS_APPLET_NAME);
 	gtk_about_dialog_set_version (about, VERSION);
 	gtk_about_dialog_set_copyright (about, _("Copyright \xc2\xa9 2006 Benjamin Canou"));
 	gtk_about_dialog_set_comments (about, GPM_BRIGHTNESS_APPLET_DESC);
@@ -782,7 +784,7 @@ gpm_applet_dialog_about_cb (BonoboUIComponent *uic, gpointer data, const gchar *
 	gtk_widget_show (GTK_WIDGET(about));
 
 	g_free (license_trans);
-	gdk_pixbuf_unref (logo);
+	g_object_unref (logo);
 }
 
 /**
@@ -793,24 +795,7 @@ gpm_applet_dialog_about_cb (BonoboUIComponent *uic, gpointer data, const gchar *
 static void
 gpm_applet_help_cb (BonoboUIComponent *uic, gpointer data, const gchar *verbname)
 {
-	GError *error = NULL;
-	GpmBrightnessApplet *applet = GPM_BRIGHTNESS_APPLET(data);
-	GnomeProgram *program = gnome_program_get ();
-
-	gnome_help_display_with_doc_id (program, "gnome-power-manager",
-					"gnome-power-manager.xml",
-					"applets-brightness", &error);
-	if (error != NULL) {
-		GtkWidget *dialog =
-			gtk_message_dialog_new (GTK_WINDOW (GTK_WIDGET(applet)->parent),
-						GTK_DIALOG_DESTROY_WITH_PARENT,
-						GTK_MESSAGE_ERROR,
-						GTK_BUTTONS_CLOSE,
-						error->message);
-		gtk_dialog_run (GTK_DIALOG (dialog));
-		gtk_widget_destroy (dialog);
-		g_error_free (error);
-	}
+	gpm_help_display ("applets-brightness");
 }
 
 /**
@@ -822,11 +807,11 @@ gpm_applet_destroy_cb (GtkObject *object)
 {
 	GpmBrightnessApplet *applet = GPM_BRIGHTNESS_APPLET(object);
 
-	if (applet->watch != NULL) {
-		g_object_unref (applet->watch);
+	if (applet->monitor != NULL) {
+		g_object_unref (applet->monitor);
 	}
 	if (applet->icon != NULL) {
-		gdk_pixbuf_unref (applet->icon);
+		g_object_unref (applet->icon);
 	}
 }
 
@@ -845,7 +830,7 @@ brightness_changed_cb (DBusGProxy          *proxy,
 		       guint	            brightness,
 		       GpmBrightnessApplet *applet)
 {
-	printf ("DEBUG: BrightnessChanged detected: %i\n", brightness);
+	egg_debug ("BrightnessChanged detected: %i\n", brightness);
 	applet->level = brightness;
 }
 
@@ -858,18 +843,18 @@ gpm_brightness_applet_dbus_connect (GpmBrightnessApplet *applet)
 	GError *error = NULL;
 
 	if (applet->connection == NULL) {
-		printf ("DEBUG: get connection\n");
+		egg_debug ("get connection\n");
 		g_clear_error (&error);
 		applet->connection = dbus_g_bus_get (DBUS_BUS_SESSION, &error);
 		if (error != NULL) {
-			printf ("WARNING: Could not connect to DBUS daemon: %s", error->message);
+			egg_warning ("Could not connect to DBUS daemon: %s", error->message);
 			g_error_free (error);
 			applet->connection = NULL;
 			return FALSE;
 		}
 	}
 	if (applet->proxy == NULL) {
-		printf ("DEBUG: get proxy\n");
+		egg_debug ("get proxy\n");
 		g_clear_error (&error);
 		applet->proxy = dbus_g_proxy_new_for_name_owner (applet->connection,
 							 GPM_DBUS_SERVICE,
@@ -877,7 +862,7 @@ gpm_brightness_applet_dbus_connect (GpmBrightnessApplet *applet)
 							 GPM_DBUS_INTERFACE_BACKLIGHT,
 							 &error);
 		if (error != NULL) {
-			printf ("WARNING: Cannot connect, maybe the daemon is not running: %s\n", error->message);
+			egg_warning ("Cannot connect, maybe the daemon is not running: %s\n", error->message);
 			g_error_free (error);
 			applet->proxy = NULL;
 			return FALSE;
@@ -900,7 +885,7 @@ gboolean
 gpm_brightness_applet_dbus_disconnect (GpmBrightnessApplet *applet)
 {
 	if (applet->proxy != NULL) {
-		printf ("DEBUG: removing proxy\n");
+		egg_debug ("removing proxy\n");
 		g_object_unref (applet->proxy);
 		applet->proxy = NULL;
 	}
@@ -908,13 +893,13 @@ gpm_brightness_applet_dbus_disconnect (GpmBrightnessApplet *applet)
 }
 
 /**
- * watch_connection_cb:
+ * monitor_connection_cb:
  * @proxy: The dbus raw proxy
  * @status: The status of the service, where TRUE is connected
  * @screensaver: This class instance
  **/
 static void
-watch_connection_cb (DbusWatch           *watch,
+monitor_connection_cb (EggDbusMonitor           *monitor,
 		     gboolean	          status,
 		     GpmBrightnessApplet *applet)
 {
@@ -936,6 +921,8 @@ watch_connection_cb (DbusWatch           *watch,
 static void
 gpm_brightness_applet_init (GpmBrightnessApplet *applet)
 {
+	DBusGConnection *connection;
+
 	/* initialize fields */
 	applet->size = 0;
 	applet->call_worked = TRUE;
@@ -950,10 +937,11 @@ gpm_brightness_applet_init (GpmBrightnessApplet *applet)
                                            GPM_DATA G_DIR_SEPARATOR_S "icons");
 
 
-	applet->watch = dbus_watch_new ();
-	g_signal_connect (applet->watch, "connection-changed",
-			  G_CALLBACK (watch_connection_cb), applet);
-	dbus_watch_assign (applet->watch, DBUS_WATCH_SESSION, GPM_DBUS_SERVICE);
+	applet->monitor = egg_dbus_monitor_new ();
+	g_signal_connect (applet->monitor, "connection-changed",
+			  G_CALLBACK (monitor_connection_cb), applet);
+	connection = dbus_g_bus_get (DBUS_BUS_SESSION, NULL);
+	egg_dbus_monitor_assign (applet->monitor, connection, GPM_DBUS_SERVICE);
 	gpm_brightness_applet_dbus_connect (applet);
 
 	/* coldplug */
