@@ -26,10 +26,6 @@
 #include <glib-object.h>
 #include <dbus/dbus-glib.h>
 
-#define	GPM_DBUS_SERVICE		"org.gnome.PowerManager"
-#define	GPM_DBUS_PATH			"/org/gnome/PowerManager"
-#define	GPM_DBUS_INTERFACE		"org.gnome.PowerManager"
-
 G_BEGIN_DECLS
 
 #define GPM_TYPE_MANAGER	 (gpm_manager_get_type ())
@@ -38,6 +34,8 @@ G_BEGIN_DECLS
 #define GPM_IS_MANAGER(o)	 (G_TYPE_CHECK_INSTANCE_TYPE ((o), GPM_TYPE_MANAGER))
 #define GPM_IS_MANAGER_CLASS(k)  (G_TYPE_CHECK_CLASS_TYPE ((k), GPM_TYPE_MANAGER))
 #define GPM_MANAGER_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), GPM_TYPE_MANAGER, GpmManagerClass))
+#define GPM_MANAGER_ERROR	 (gpm_manager_error_quark ())
+#define GPM_MANAGER_TYPE_ERROR	 (gpm_manager_error_get_type ()) 
 
 typedef struct GpmManagerPrivate GpmManagerPrivate;
 
@@ -50,56 +48,34 @@ typedef struct
 typedef struct
 {
 	GObjectClass	parent_class;
-	void		(* on_ac_changed)		(GpmManager	*manager,
-							 gboolean	 on_ac);
 } GpmManagerClass;
 
 typedef enum
 {
-	 GPM_MANAGER_ERROR_GENERAL
+	GPM_MANAGER_ERROR_DENIED,
+	GPM_MANAGER_ERROR_NO_HW,
+	GPM_MANAGER_ERROR_LAST
 } GpmManagerError;
 
-#define GPM_MANAGER_ERROR gpm_manager_error_quark ()
 
 GQuark		 gpm_manager_error_quark		(void);
+GType		 gpm_manager_error_get_type		(void);
 GType		 gpm_manager_get_type		  	(void);
 GpmManager	*gpm_manager_new			(void);
 
-gboolean	 gpm_manager_get_on_ac			(GpmManager	*manager,
-							 gboolean	*retval,
+gboolean	 gpm_manager_suspend			(GpmManager	*manager,
 							 GError		**error);
-gboolean	 gpm_manager_get_low_power_mode		(GpmManager	*manager,
-							 gboolean	*retval,
+gboolean	 gpm_manager_hibernate			(GpmManager	*manager,
 							 GError		**error);
-gboolean	 gpm_manager_allowed_shutdown		(GpmManager	*manager,
-							 gboolean	*allowed,
+gboolean	 gpm_manager_can_suspend		(GpmManager	*manager,
+							 gboolean	*can_suspend,
 							 GError		**error);
-gboolean	 gpm_manager_allowed_reboot		(GpmManager	*manager,
-							 gboolean	*allowed,
+gboolean	 gpm_manager_can_hibernate		(GpmManager	*manager,
+							 gboolean	*can_hibernate,
 							 GError		**error);
-gboolean	 gpm_manager_allowed_suspend		(GpmManager	*manager,
-							 gboolean	*allowed,
+gboolean	 gpm_manager_get_preferences_options	(GpmManager	*manager,
+							 gint		*capability,
 							 GError		**error);
-gboolean	 gpm_manager_allowed_hibernate		(GpmManager	*manager,
-							 gboolean	*allowed,
-							 GError		**error);
-gboolean	 gpm_manager_suspend_dbus_method	(GpmManager	*manager,
-							 GError		**error);
-gboolean	 gpm_manager_hibernate_dbus_method	(GpmManager	*manager,
-							 GError		**error);
-gboolean	 gpm_manager_shutdown_dbus_method	(GpmManager	*manager,
-						 	 GError		**error);
-gboolean	 gpm_manager_reboot_dbus_method		(GpmManager	*manager,
-						 	 GError		**error);
-void		 gpm_manager_inhibit			(GpmManager	*manager,
-						   	 const gchar	*application,
-							 const gchar	*reason,
-							 DBusGMethodInvocation *context,
-							 GError		**error);
-void		 gpm_manager_uninhibit			(GpmManager	*manager,
-						 	 guint32	 cookie,
-				   			 DBusGMethodInvocation *context,
-				   			 GError		**error);
 
 G_END_DECLS
 
