@@ -122,21 +122,21 @@ gpm_marshal_VOID__STRING_STRING (GClosure     *closure,
             data2);
 }
 
-/* NONE:UINT,STRING,STRING (gpm-marshal.list:3) */
+/* NONE:POINTER,STRING,STRING (gpm-marshal.list:3) */
 void
-gpm_marshal_VOID__UINT_STRING_STRING (GClosure     *closure,
-                                      GValue       *return_value G_GNUC_UNUSED,
-                                      guint         n_param_values,
-                                      const GValue *param_values,
-                                      gpointer      invocation_hint G_GNUC_UNUSED,
-                                      gpointer      marshal_data)
+gpm_marshal_VOID__POINTER_STRING_STRING (GClosure     *closure,
+                                         GValue       *return_value G_GNUC_UNUSED,
+                                         guint         n_param_values,
+                                         const GValue *param_values,
+                                         gpointer      invocation_hint G_GNUC_UNUSED,
+                                         gpointer      marshal_data)
 {
-  typedef void (*GMarshalFunc_VOID__UINT_STRING_STRING) (gpointer     data1,
-                                                         guint        arg_1,
-                                                         gpointer     arg_2,
-                                                         gpointer     arg_3,
-                                                         gpointer     data2);
-  register GMarshalFunc_VOID__UINT_STRING_STRING callback;
+  typedef void (*GMarshalFunc_VOID__POINTER_STRING_STRING) (gpointer     data1,
+                                                            gpointer     arg_1,
+                                                            gpointer     arg_2,
+                                                            gpointer     arg_3,
+                                                            gpointer     data2);
+  register GMarshalFunc_VOID__POINTER_STRING_STRING callback;
   register GCClosure *cc = (GCClosure*) closure;
   register gpointer data1, data2;
 
@@ -152,10 +152,10 @@ gpm_marshal_VOID__UINT_STRING_STRING (GClosure     *closure,
       data1 = g_value_peek_pointer (param_values + 0);
       data2 = closure->data;
     }
-  callback = (GMarshalFunc_VOID__UINT_STRING_STRING) (marshal_data ? marshal_data : cc->callback);
+  callback = (GMarshalFunc_VOID__POINTER_STRING_STRING) (marshal_data ? marshal_data : cc->callback);
 
   callback (data1,
-            g_marshal_value_peek_uint (param_values + 1),
+            g_marshal_value_peek_pointer (param_values + 1),
             g_marshal_value_peek_string (param_values + 2),
             g_marshal_value_peek_string (param_values + 3),
             data2);
