@@ -1,3 +1,4 @@
+#! /bin/sh
 # Copyright (C) 2006-2007 Richard Hughes <richard@hughsie.com>
 #
 # Licensed under the GNU General Public License Version 2
@@ -71,6 +72,9 @@ lshal | grep "battery\."
 
 OS=`uname -s`
 
+echo "DeviceKit data:"
+devkit-power --dump
+
 echo "GNOME Power Manager Process Information:"
 if [ "$OS" = "SunOS" ]; then
 	ptree -a `pgrep power`
